<?php
/**
 * Created by PhpStorm.
 * User: matheussilva
 * Date: 10/06/14
 * Time: 10:34
 */

namespace Folha\Logic\ObrigacaoLegal\RAIS;


use HCM\Util\DateUtil;

use \Folha\Repositories\FpaIncidevento;

use \Folha\Repositories\FpaCalculofolha;

use \Folha\Repositories\GpeAltesitufunc;

use \Folha\Repositories\GpePessoa;

class Rais02 {

    const ASSOCIATIVA  = 1;
    const CONFEDERATIVA   = 2;
    const SINDICAL     = 3;
    const ASSISTENCIAL = 4;

    const DT_ADIANTAMENTO = 1;
    const DT_RESTANTE = 2;


    private $info;


    /**
     * Recebe as filiais e os vínculos que estarão na RAIS
     * @param array $nrestruturam
     * @param array $nrvinculos
     * @param $nrorg
     * @param $ano
     */
    function __construct($nrorg, $ano, $grupoIncidencia, $nrestruturam = array(), $nrvinculos = array(null))
    {
        $this->info = $this->getTipo02($nrorg, $ano, $nrestruturam, $nrvinculos);
        $this->consolida($nrorg, $ano, $grupoIncidencia);
    }

    /**
     * @return array|bool
     */
    public function getInfo()
    {
        return $this->info;
    }

    /**
     * @param array $nrestruturam
     * @param array $nrvinculos
     * @param $nrorg
     * @param $ano
     * @return array|bool
     */
    private function getTipo02($nrorg, $ano, $nrestruturam = array(), $nrvinculos = array(null))
    {
        if(is_array($nrestruturam)){
            $nrestruturam = implode(' ,', $nrestruturam);
        }
        if(is_array($nrvinculos)){
            $nrvinculos = implode(' OR NRVINCULOM = ', $nrvinculos);
        }


        return GpePessoa::getTipo2Rais($ano, $nrorg, $nrestruturam, $nrvinculos);
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @return bool
     */
    private function getHorasExtras($nrvinculom, $nrorg, $ano, $grupoIncidencia)
    {
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = FpaCalculofolha::getHorasExtrasRais($nrvinculom, $nrorg, $inicio, $final, $grupoIncidencia);
        return ($info)?$info[0]:'000';
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @return bool
     */
    private function getSalarioMes($nrvinculom, $nrorg, $ano, $grupoIncidencia)
    {
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = FpaIncidevento::getSalarioRais($nrvinculom, $nrorg, $inicio, $final, $grupoIncidencia);
        return ($info)?($info[0]):'000000000';
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @param $tipo
     * @param int $num
     * @return bool
     */
    private function getContribuicao($nrvinculom, $nrorg, $ano,  $tipo, $num = 1)
    {
        $data_inicio = "01/01/$ano";
        $data_final = "31/12/$ano";
        switch($tipo){
            case(self::ASSOCIATIVA):{
                $evento = array(1070, 1000965);
                $info = FpaCalculofolha::getContrubuicoes($nrvinculom, $nrorg,$evento, $data_inicio, $data_final);
                return (isset($info[$num-1]))?($info[$num-1]):(null);
            }
            case(self::CONFEDERATIVA):{
                $evento = array(100174, 1075);
                $info = FpaCalculofolha::getContrubuicoes($nrvinculom, $nrorg,$evento, $data_inicio, $data_final);
                return (isset($info[0]))?($info[0]):(null);
            }
            case(self::SINDICAL):{
                $evento = 1060;
                $info = FpaCalculofolha::getContrubuicoes($nrvinculom, $nrorg, $evento, $data_inicio, $data_final);
                return (isset($info[0]))?($info[0]):(null);
            }
            case(self::ASSISTENCIAL):{
                $evento = array(1065, 1000924);
                $info = FpaCalculofolha::getContrubuicoes($nrvinculom, $nrorg, $evento, $data_inicio, $data_final);
                return (isset($info[0]))?($info[0]):null;
            }
        }
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @param int $num
     * @return bool
     */
    private function getAfastamento($nrvinculom, $nrorg, $ano, $num = 1)
    {
        $dataInicio = "01/01/$ano";
        $dataFinal  = "31/12/$ano";
        $info = GpeAltesitufunc::getAfastamento($nrvinculom, $nrorg, $dataInicio, $dataFinal);
        return (isset($info[$num-1]))?$info[$num-1]:null;
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @return bool
     */
    private function getTotalAfastamento($nrvinculom, $nrorg, $ano)
    {
        $dataInicio = "01/01/$ano";
        $dataFinal  = "31/12/$ano";
        $info = GpeAltesitufunc::getTotalAfastamento($nrvinculom, $nrorg, $dataInicio, $dataFinal);
        return ($info)?($info[0]['TEMPO']):null;
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @param $tipo
     * @return bool
     */
    private function getDecimoTerceiro($nrvinculom, $nrorg, $ano, $tipo)
    {
        if($tipo == self::DT_ADIANTAMENTO)
            $nreventom = 120;
        else
            $nreventom = 110;

        $data_inicio = "01/01/$ano";
        $data_final  = "31/12/$ano";
        $info = FpaCalculofolha::getDecimoTerceiro($nrvinculom, $nrorg, $data_inicio, $data_final, $nreventom);
        return ($info)?$info[0]:null;

    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @return bool
     */
    public function getFeriasIndenizada($nrvinculom, $nrorg, $ano)
    {
        $nreventom = "570, 515, 510, 270, 275, 505, 500";
        $nrtipomoviment = "1, 5, 6, 9";
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = FpaCalculofolha::getFeriasIndenizada($nrvinculom, $nrorg, $inicio, $final, $nreventom, $nrtipomoviment);
        return ($info)?$info[0]['VALOR']*100:'00000000';
    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @param $dataRecisao
     * @param $dataAvisoPrevio
     * @return null
     */
    private function getAvisoPrevioIndenizado($nrvinculom, $nrorg, $ano, $dataRecisao, $dataAvisoPrevio )
    {
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = Fpacalculofolha::getAvisoPrevioIndenizado($nrvinculom, $nrorg, $inicio, $final, $dataRecisao, $dataAvisoPrevio);
        return ($info)?($info[0]['VREVENTOFOLHA']*100):null;

    }

    /**
     * @param $nrvinculom
     * @param $nrorg
     * @param $ano
     * @return null
     */
    private function getGratificacoes($nrvinculom, $nrorg, $ano)
    {
        $nreventom = "140, 150, 175, 160, 170";
        $nrtipomoviment = "1, 5, 6, 9";
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = Fpacalculofolha::getGratificacoes($nrvinculom, $nrorg, $inicio, $final, $nreventom, $nrtipomoviment);
        return ($info)?($info[0]['VREVENTOFOLHA']*100):null;
    }

    private function getDissidio($nrvinculom, $nrorg, $ano)
    {
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";

        $info = Fpacalculofolha::getDissidio($nrvinculom, $nrorg, $inicio, $final);
        return ($info)?($info[0]):null;
    }

    private function getMultaRecisao($nrvinculom, $nrorg, $ano)
    {
        $inicio = "01/01/$ano";
        $final = "31/12/$ano";
        $nreventom = 430;

        $info = FpaCalculofolha::getDecimoTerceiro($nrvinculom, $nrorg, $inicio, $final, $nreventom);
        return ($info)?$info[0]['VALOR_TOTAL']:null;


    }

    /**
     * @param $nrorg
     * @param $ano
     */
    private function consolida($nrorg, $ano, $grupoIncidencia)
    {
        $tam = count($this->info);
        for($c = 0; $c<$tam; $c++){

            $nrvinculom = $this->info[$c]['NRVINCULOM'];

            //Salários

            $salario               = $this->getSalarioMes($nrvinculom, $nrorg, $ano, $grupoIncidencia);

            //Afastamento

            $primeiro_afastamento  = $this->getAfastamento($nrvinculom, $nrorg, $ano, 1);
            $segundo_afastamento   = $this->getAfastamento($nrvinculom, $nrorg, $ano, 2);
            $terceiro_afastamento  = $this->getAfastamento($nrvinculom, $nrorg, $ano, 3);
            $total_afastamento     = $this->getTotalAfastamento($nrvinculom, $nrorg, $ano);

            //Horas Extras

            $horasExtras           = $this->getHorasExtras($nrvinculom, $nrorg, $ano, $grupoIncidencia);

            //Contribuição

            $primeira_associativa  = $this->getContribuicao($nrvinculom, $nrorg, $ano, self::ASSOCIATIVA, 1);
            $segunda_associativa   = $this->getContribuicao($nrvinculom, $nrorg, $ano, self::ASSOCIATIVA, 2);
            $sindical              = $this->getContribuicao($nrvinculom, $nrorg, $ano, self::SINDICAL);
            $assistencial          = $this->getContribuicao($nrvinculom, $nrorg, $ano, self::ASSISTENCIAL);
            $confederativa         = $this->getContribuicao($nrvinculom, $nrorg, $ano, self::CONFEDERATIVA);

            //Décimo Terceiro

            $dt_adiantamento      = $this->getDecimoTerceiro($nrvinculom, $nrorg, $ano, self::DT_ADIANTAMENTO);
            $dt_restante          = $this->getDecimoTerceiro($nrvinculom, $nrorg, $ano, self::DT_RESTANTE);
            $dt_restante         -= $dt_adiantamento;

            //Férias Indenizadas

            $f_indenizada         = $this->getFeriasIndenizada($nrvinculom, $nrorg, $ano);

            //Gratificações

            $gratificacoes        = $this->getGratificacoes($nrvinculom, $nrorg, $ano);

            //Aviso Prévio Indenizado

            $av_indenizado        = $this->getAvisoPrevioIndenizado($nrvinculom, $nrorg, $ano, $this->info[$c]['DTRESCISAOVINC'], $this->info[$c]['DTAVISOPREVIO']);

            //Dissídio

            $dissido              = $this->getDissidio($nrvinculom, $nrorg, $ano);

            //Multa Recisão

            $multa_recisao        = $this->getMultaRecisao($nrvinculom, $nrorg, $ano);

            //Setar os valores dentro das variável

            $this->info[$c]['HORAS_EXTRA_JANEIRO']    = \Valor::arredonda($horasExtras['JANEIRO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_FEVEREIRO']  = \Valor::arredonda($horasExtras['FEVEREIRO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_MARCO']      = \Valor::arredonda($horasExtras['MARCO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_ABRIL']      = \Valor::arredonda($horasExtras['ABRIL'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_MAIO']       = \Valor::arredonda($horasExtras['MAIO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_JUNHO']      = \Valor::arredonda($horasExtras['JUNHO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_JULHO']      = \Valor::arredonda($horasExtras['JULHO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_AGOSTO']     = \Valor::arredonda($horasExtras['AGOSTO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_SETEMBRO']   = \Valor::arredonda($horasExtras['SETEMBRO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_OUTUBRO']    = \Valor::arredonda($horasExtras['OUTUBRO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_NOVEMBRO']   = \Valor::arredonda($horasExtras['NOVEMBRO'], \Valor::TOTAL, 0, 5);
            $this->info[$c]['HORAS_EXTRA_DEZEMBRO']   = \Valor::arredonda($horasExtras['DEZEMBRO'], \Valor::TOTAL, 0, 5);

            $this->info[$c]['REMUNERACAO_JANEIRO']    = $salario['JANEIRO'];
            $this->info[$c]['REMUNERACAO_FEVEREIRO']  = $salario['FEVEREIRO'];
            $this->info[$c]['REMUNERACAO_MARCO']      = $salario['MARCO'];
            $this->info[$c]['REMUNERACAO_ABRIL']      = $salario['ABRIL'];
            $this->info[$c]['REMUNERACAO_MAIO']       = $salario['MAIO'];
            $this->info[$c]['REMUNERACAO_JUNHO']      = $salario['JUNHO'];
            $this->info[$c]['REMUNERACAO_JULHO']      = $salario['JULHO'];
            $this->info[$c]['REMUNERACAO_AGOSTO']     = $salario['AGOSTO'];
            $this->info[$c]['REMUNERACAO_SETEMBRO']   = $salario['SETEMBRO'];
            $this->info[$c]['REMUNERACAO_OUTUBRO']    = $salario['OUTUBRO'];
            $this->info[$c]['REMUNERACAO_NOVEMBRO']   = $salario['NOVEMBRO'];
            $this->info[$c]['REMUNERACAO_DEZEMBRO']   = $salario['DEZEMBRO'];

            $this->info[$c]['PRIMEIRO_AFASTAMENTO']   = ($primeiro_afastamento) ?  $primeiro_afastamento['CODRAIS']            :  null;
            $this->info[$c]['DT_INI_PRI_AFASTAMEN']   = ($primeiro_afastamento) ?  $primeiro_afastamento['DTINISITUFUNC']      :  null;
            $this->info[$c]['DT_FIM_PRI_AFASTAMEN']   = ($primeiro_afastamento) ?  $primeiro_afastamento['DTFIMSITUFUNC']      :  null;
            $this->info[$c]['SEGUNDO_AFASTAMENTO']    = ($segundo_afastamento)  ?  $segundo_afastamento['CODRAIS']             :  null;
            $this->info[$c]['DT_INI_SEG_AFASTAMEN']   = ($segundo_afastamento)  ?  $segundo_afastamento['DTINISITUFUNC']       :  null;
            $this->info[$c]['DT_FIM_SEG_AFASTAMEN']   = ($segundo_afastamento)  ?  $segundo_afastamento['DTFIMSITUFUNC']       :  null;
            $this->info[$c]['TERCEIRO_AFASTAMENTO']   = ($terceiro_afastamento) ?  $terceiro_afastamento['CODRAIS']            :  null;
            $this->info[$c]['DT_INI_TER_AFASTAMEN']   = ($terceiro_afastamento) ?  $terceiro_afastamento['DTINISITUFUNC']      :  null;
            $this->info[$c]['DT_FIM_TER_AFASTAMEN']   = ($terceiro_afastamento) ?  $terceiro_afastamento['DTFIMSITUFUNC']      :  null;
            $this->info[$c]['DIAS_AFASTAMENTO']       = $total_afastamento;

            $this->info[$c]['CNPJ_CONT_ASSOC_1']      = ($primeira_associativa)  ?  $primeira_associativa['CDCNPJESTRUT']      : null;
            $this->info[$c]['VALOR_CONT_ASSOC_1']     = ($primeira_associativa)  ?  $primeira_associativa['VREVENTOFOLHA']*100 : null;
            $this->info[$c]['CNPJ_CONT_ASSOC_2']      = ($segunda_associativa)   ?  $segunda_associativa['CDCNPJESTRUT']       : null;
            $this->info[$c]['VALOR_CONT_ASSOC_2']     = ($segunda_associativa)   ?  $segunda_associativa['VREVENTOFOLHA']*100  : null;
            $this->info[$c]['CNPJ_CONT_SINDI']        = ($sindical)              ?  $sindical['CDCNPJESTRUT']                  : null;
            $this->info[$c]['VALOR_CONT_SINDI']       = ($sindical)              ?  $sindical['VREVENTOFOLHA']*100             : null;
            $this->info[$c]['CNPJ_CONT_ASSIST']       = ($assistencial)          ?  $assistencial['CDCNPJESTRUT']              : null;
            $this->info[$c]['VALOR_CONT_ASSIST']      = ($assistencial)          ?  $assistencial['VREVENTOFOLHA']*100         : null;
            $this->info[$c]['CNPJ_CONT_CONFED']       = ($confederativa)         ?  $confederativa['CDCNPJESTRUT']             : null;
            $this->info[$c]['VALOR_CONT_CONFED']      = ($confederativa)         ?  $confederativa['VREVENTOFOLHA']*100        : null;

            $this->info[$c]['ADIANTAMENTO_DTERCEIRO'] = ($dt_adiantamento)       ?  $dt_adiantamento['VALOR_TOTAL']*100        : null;
            $this->info[$c]['MES_ADIANT_DTERCEIRO']   = ($dt_adiantamento)       ?  $dt_adiantamento['DTOCORRENCIA']           : null;
            $this->info[$c]['RESTANTE_DTERCEIRO']     = ($dt_restante)           ?  $dt_restante['VALOR_TOTAL']*100            : null;
            $this->info[$c]['MES_RESTANT_DTERCEIRO']  = ($dt_restante)           ?  $dt_restante['DTOCORRENCIA']               : null;

            $this->info[$c]['FERIAS_INDENIZADAS']     = $f_indenizada;

            $this->info[$c]['VALOR_GRATIFICACAO']     = ($gratificacoes)         ?  $gratificacoes['VALOR']*100                : null;
            $this->info[$c]['MESES_GRATIFICACAO']     = ($gratificacoes)         ?  $gratificacoes['QUANT_MESES']              : null;

            $this->info[$c]['AVISO_INDENIZADO']       = $av_indenizado;

            $this->info[$c]['VALOR_DISSIDIO']         = ($dissido)               ?  $dissido['VRDIFEREALTE']*100               : null;
            $this->info[$c]['MESES_DISSIDIO']         = ($dissido)               ?  $dissido['QUANTMESES']                     : null;

            $this->info[$c]['MULTA_REC_SEM_JUSTCAUSA']= $multa_recisao;

        }
    }


} 